import setuptools

setuptools.setup(
    name='pytiers',
    version='2.1.7',
    author='Huang Bo-Xuan',
    author_email='r09142003@gmail.com',
    install_requires=[
        'seaborn',
        'matplotlib',
        'pandas',
        'plotly',
        'nbformat>=4.2.0',
        'numpy'
    ]
)
