"""Methods for referenceing Point objects: by.TIME, by.INDEX, by.POINT\nEssentially integers.\nUsage example:\n pytiers.get_point(1, by.INDEX)\n returns the point in the Tier object with the #1 index."""

TIME = 0
INDEX = 1
POINT = 2

by_methods = [0, 1, 2]